@@ -3,12 +3,12 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { appEventBus } from "./event-bus";
+import { EventEmitter } from "../event-emitter";
+import type { AppEvent } from "./event-bus";
 
 const appEventBusInjectable = getInjectable({
   id: "app-event-bus",
-  instantiate: () => appEventBus,
-  causesSideEffects: true,
+  instantiate: () => new EventEmitter<[AppEvent]>,
   decorable: false,
 });
 
