@@ -4,9 +4,10 @@
  */
 import type { app as electronApp } from "electron";
 
-export type PathName = Parameters<typeof electronApp["getPath"]>[0];
+export type PathName = Parameters<typeof electronApp["getPath"]>[0] | "currentApp";
 
 export const pathNames: PathName[] = [
+  "currentApp",
   "home",
   "appData",
   "userData",
