@@ -3,11 +3,11 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { appPathsInjectionToken } from "../app-path-injection-token";
+import appPathsInjectable from "../app-paths.injectable";
 
 const directoryForTempInjectable = getInjectable({
   id: "directory-for-temp",
-  instantiate: (di) => di.inject(appPathsInjectionToken).temp,
+  instantiate: (di) => di.inject(appPathsInjectable).temp,
 });
 
 export default directoryForTempInjectable;
