@@ -5,8 +5,7 @@
 
 import { navigate } from "../../renderer/navigation";
 import type { CatalogEntityMetadata, CatalogEntitySpec, CatalogEntityStatus } from "../catalog";
-import { CatalogCategory, CatalogEntity } from "../catalog";
-import { catalogCategoryRegistry } from "../catalog/catalog-category-registry";
+import { CatalogCategory, CatalogEntity, categoryVersion } from "../catalog/catalog-entity";
 
 interface GeneralEntitySpec extends CatalogEntitySpec {
   path: string;
@@ -23,18 +22,6 @@ export class GeneralEntity extends CatalogEntity<CatalogEntityMetadata, CatalogE
   async onRun() {
     navigate(this.spec.path);
   }
-
-  public onSettingsOpen(): void {
-    return;
-  }
-
-  public onDetailsOpen(): void {
-    return;
-  }
-
-  public onContextMenuOpen(): void {
-    return;
-  }
 }
 
 export class GeneralCategory extends CatalogCategory {
@@ -47,15 +34,10 @@ export class GeneralCategory extends CatalogCategory {
   public spec = {
     group: "entity.k8slens.dev",
     versions: [
-      {
-        name: "v1alpha1",
-        entityClass: GeneralEntity,
-      },
+      categoryVersion("v1alpha1", GeneralEntity),
     ],
     names: {
       kind: "General",
     },
   };
 }
-
-catalogCategoryRegistry.add(new GeneralCategory());
