@@ -5,6 +5,7 @@
 import type { KubeConfig } from "@kubernetes/client-node";
 import { CoreV1Api } from "@kubernetes/client-node";
 import { getInjectable } from "@ogre-tools/injectable";
+import { isDefined } from "../utils";
 
 export type ListNamespaces = () => Promise<string[]>;
 
@@ -14,7 +15,9 @@ export function listNamespaces(config: KubeConfig): ListNamespaces {
   return async () => {
     const { body: { items }} = await coreApi.listNamespace();
 
-    return items.map(ns => ns.metadata.name);
+    return items
+      .map(ns => ns.metadata?.name)
+      .filter(isDefined);
   };
 }
 
