@@ -4,16 +4,16 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import directoryForUserDataInjectable from "../app-paths/directory-for-user-data/directory-for-user-data.injectable";
-import getAbsolutePathInjectable from "../path/get-absolute-path.injectable";
+import joinPathsInjectable from "../path/join-paths.injectable";
 
 const directoryForLensLocalStorageInjectable = getInjectable({
   id: "directory-for-lens-local-storage",
 
   instantiate: (di) => {
-    const getAbsolutePath = di.inject(getAbsolutePathInjectable);
+    const joinPaths = di.inject(joinPathsInjectable);
     const directoryForUserData = di.inject(directoryForUserDataInjectable);
 
-    return getAbsolutePath(
+    return joinPaths(
       directoryForUserData,
       "lens-local-storage",
     );
