@@ -3,18 +3,18 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import type * as FetchModule from "node-fetch";
-
-const { NodeFetch: { default: fetch }} = require("../../../build/webpack/node-fetch.bundle") as { NodeFetch: typeof FetchModule };
-
-type Response = FetchModule.Response;
-type RequestInit = FetchModule.RequestInit;
+import type { RequestInit, Response } from "node-fetch";
+import nodeFetchModuleInjectable from "./fetch-module.injectable";
 
 export type Fetch = (url: string, init?: RequestInit) => Promise<Response>;
 
 const fetchInjectable = getInjectable({
   id: "fetch",
-  instantiate: (): Fetch => fetch,
+  instantiate: (di): Fetch => {
+    const { default: fetch } = di.inject(nodeFetchModuleInjectable);
+
+    return (url, init) => fetch(url, init);
+  },
   causesSideEffects: true,
 });
 
