@@ -3,24 +3,20 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import isAllowedResourceInjectable from "../../../../../utils/is-allowed-resource.injectable";
+import { shouldShowResourceInjectionToken } from "../../../../../cluster-store/allowed-resources-injection-token";
 import { frontEndRouteInjectionToken } from "../../../../front-end-route-injection-token";
 
 const limitRangesRouteInjectable = getInjectable({
   id: "limit-ranges-route",
 
-  instantiate: (di) => {
-    const limitRangesIsAllowed = di.inject(
-      isAllowedResourceInjectable,
-      "limitranges",
-    );
-
-    return {
-      path: "/limitranges",
-      clusterFrame: true,
-      isEnabled: limitRangesIsAllowed,
-    };
-  },
+  instantiate: (di) => ({
+    path: "/limitranges",
+    clusterFrame: true,
+    isEnabled: di.inject(shouldShowResourceInjectionToken, {
+      apiName: "limitranges",
+      group: "v1",
+    }),
+  }),
 
   injectionToken: frontEndRouteInjectionToken,
 });
