@@ -5,10 +5,8 @@
 
 export const clusterActivateHandler = "cluster:activate";
 export const clusterSetFrameIdHandler = "cluster:set-frame-id";
-export const clusterRefreshHandler = "cluster:refresh";
+export const clusterVisibilityHandler = "cluster:visibility";
 export const clusterDisconnectHandler = "cluster:disconnect";
-export const clusterKubectlApplyAllHandler = "cluster:kubectl-apply-all";
-export const clusterKubectlDeleteAllHandler = "cluster:kubectl-delete-all";
 export const clusterStates = "cluster:states";
 
 /**
