@@ -5,7 +5,7 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { apiKubePrefix } from "../vars";
 import isDebuggingInjectable from "../vars/is-debugging.injectable";
-import { apiBaseInjectionToken } from "./api-base";
+import { apiBaseHostHeaderInjectionToken, apiBaseServerAddressInjectionToken } from "./api-base-configs";
 import createKubeJsonApiInjectable from "./create-kube-json-api.injectable";
 import type { KubeJsonApi } from "./kube-json-api";
 
@@ -14,19 +14,18 @@ export type CreateKubeJsonApiForCluster = (clusterId: string) => KubeJsonApi;
 const createKubeJsonApiForClusterInjectable = getInjectable({
   id: "create-kube-json-api-for-cluster",
   instantiate: (di): CreateKubeJsonApiForCluster => {
-    const apiBase = di.inject(apiBaseInjectionToken);
     const createKubeJsonApi = di.inject(createKubeJsonApiInjectable);
     const isDebugging = di.inject(isDebuggingInjectable);
 
     return (clusterId) => createKubeJsonApi(
       {
-        serverAddress: apiBase.config.serverAddress,
+        serverAddress: di.inject(apiBaseServerAddressInjectionToken),
         apiBase: apiKubePrefix,
         debug: isDebugging,
       },
       {
         headers: {
-          "Host": `${clusterId}.localhost:${new URL(apiBase.config.serverAddress).port}`,
+          "Host": `${clusterId}.${di.inject(apiBaseHostHeaderInjectionToken)}`,
         },
       },
     );
