@@ -4,7 +4,7 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { urlBuilderFor } from "../../../utils/buildUrl";
-import { apiBaseInjectionToken } from "../../api-base";
+import apiBaseInjectable from "../../api-base.injectable";
 
 export type RequestDeleteHelmRelease = (name: string, namespace: string) => Promise<void>;
 
@@ -13,7 +13,7 @@ const requestDeleteEndpoint = urlBuilderFor("/v2/releases/:namespace/:name");
 const requestDeleteHelmReleaseInjectable = getInjectable({
   id: "request-delete-helm-release",
   instantiate: (di): RequestDeleteHelmRelease => {
-    const apiBase = di.inject(apiBaseInjectionToken);
+    const apiBase = di.inject(apiBaseInjectable);
 
     return (name, namespace) => apiBase.del(requestDeleteEndpoint.compile({ name, namespace }));
   },
