@@ -4,7 +4,7 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { urlBuilderFor } from "../../../utils/buildUrl";
-import { apiBaseInjectionToken } from "../../api-base";
+import apiBaseInjectable from "../../api-base.injectable";
 
 export type RequestHelmReleaseRollback = (name: string, namespace: string, revision: number) => Promise<void>;
 
@@ -13,7 +13,7 @@ const requestRollbackEndpoint = urlBuilderFor("/v2/releases/:namespace/:name");
 const requestHelmReleaseRollbackInjectable = getInjectable({
   id: "request-helm-release-rollback",
   instantiate: (di): RequestHelmReleaseRollback => {
-    const apiBase = di.inject(apiBaseInjectionToken);
+    const apiBase = di.inject(apiBaseInjectable);
 
     return async (name, namespace, revision) => {
       await apiBase.put(
