@@ -3,5 +3,9 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 export type AsyncResult<Response, Error = string> =
-  | { callWasSuccessful: true; response: Response }
+  | (
+    Response extends void
+    ? { callWasSuccessful: true; response?: undefined }
+    : { callWasSuccessful: true; response: Response }
+  )
   | { callWasSuccessful: false; error: Error };
