@@ -3,17 +3,17 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
+import appPathsInjectable from "../app-paths/app-paths.injectable";
 import joinPathsInjectable from "../path/join-paths.injectable";
-import lensResourcesDirInjectable from "./lens-resources-dir.injectable";
 
 const staticFilesDirectoryInjectable = getInjectable({
   id: "static-files-directory",
 
   instantiate: (di) => {
     const joinPaths = di.inject(joinPathsInjectable);
-    const lensResourcesDir = di.inject(lensResourcesDirInjectable);
+    const currentAppDir = di.inject(appPathsInjectable).currentApp;
 
-    return joinPaths(lensResourcesDir, "static");
+    return joinPaths(currentAppDir, "static");
   },
 });
 
