@@ -3,7 +3,8 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import { UserStore } from "../../common/user-store";
+import userStoreInjectable from "../../common/user-store/user-store.injectable";
+import { asLegacyGlobalForExtensionApi } from "../as-legacy-globals-for-extension-api/as-legacy-global-object-for-extension-api";
 export interface UserPreferenceExtensionItems {
   /**
    * Get the configured kubectl binaries path.
@@ -11,6 +12,8 @@ export interface UserPreferenceExtensionItems {
   getKubectlPath: () => string | undefined;
 }
 
+const userStore = asLegacyGlobalForExtensionApi(userStoreInjectable);
+
 export const Preferences: UserPreferenceExtensionItems = {
-  getKubectlPath: () => UserStore.getInstance().kubectlBinariesPath,
+  getKubectlPath: () => userStore.kubectlBinariesPath,
 };
