@@ -10,8 +10,6 @@ import extensionsStoreInjectable from "../extensions-store/extensions-store.inje
 import extensionInstallationStateStoreInjectable from "../extension-installation-state-store/extension-installation-state-store.injectable";
 import installExtensionInjectable from "../extension-installer/install-extension/install-extension.injectable";
 import extensionPackageRootDirectoryInjectable from "../extension-installer/extension-package-root-directory/extension-package-root-directory.injectable";
-import installExtensionsInjectable from "../extension-installer/install-extensions/install-extensions.injectable";
-import staticFilesDirectoryInjectable from "../../common/vars/static-files-directory.injectable";
 import readJsonFileInjectable from "../../common/fs/read-json-file.injectable";
 import loggerInjectable from "../../common/logger.injectable";
 import pathExistsInjectable from "../../common/fs/path-exists.injectable";
@@ -27,8 +25,9 @@ import getBasenameOfPathInjectable from "../../common/path/get-basename.injectab
 import getDirnameOfPathInjectable from "../../common/path/get-dirname.injectable";
 import getRelativePathInjectable from "../../common/path/get-relative-path.injectable";
 import joinPathsInjectable from "../../common/path/join-paths.injectable";
-import removePathInjectable from "../../common/fs/remove-path.injectable";
+import removePathInjectable from "../../common/fs/remove.injectable";
 import homeDirectoryPathInjectable from "../../common/os/home-directory-path.injectable";
+import lensResourcesDirInjectable from "../../common/vars/lens-resources-dir.injectable";
 
 const extensionDiscoveryInjectable = getInjectable({
   id: "extension-discovery",
@@ -39,9 +38,8 @@ const extensionDiscoveryInjectable = getInjectable({
     extensionInstallationStateStore: di.inject(extensionInstallationStateStoreInjectable),
     isCompatibleExtension: di.inject(isCompatibleExtensionInjectable),
     installExtension: di.inject(installExtensionInjectable),
-    installExtensions: di.inject(installExtensionsInjectable),
     extensionPackageRootDirectory: di.inject(extensionPackageRootDirectoryInjectable),
-    staticFilesDirectory: di.inject(staticFilesDirectoryInjectable),
+    resourcesDirectory: di.inject(lensResourcesDirInjectable),
     readJsonFile: di.inject(readJsonFileInjectable),
     pathExists: di.inject(pathExistsInjectable),
     watch: di.inject(watchInjectable),
