@@ -12,7 +12,6 @@ import type { ExtensionsStore } from "../extensions-store/extensions-store";
 import type { ExtensionLoader } from "../extension-loader";
 import type { LensExtensionId, LensExtensionManifest } from "../lens-extension";
 import type { ExtensionInstallationStateStore } from "../extension-installation-state-store/extension-installation-state-store";
-import type { PackageJson } from "type-fest";
 import { extensionDiscoveryStateChannel } from "../../common/ipc/extension-handling";
 import { requestInitialExtensionDiscovery } from "../../renderer/ipc";
 import type { ReadJson } from "../../common/fs/read-json-file.injectable";
@@ -20,7 +19,6 @@ import type { Logger } from "../../common/logger";
 import type { PathExists } from "../../common/fs/path-exists.injectable";
 import type { Watch } from "../../common/fs/watch/watch.injectable";
 import type { Stats } from "fs";
-import { constants } from "fs";
 import type { LStat } from "../../common/fs/lstat.injectable";
 import type { ReadDirectory } from "../../common/fs/read-directory.injectable";
 import type { EnsureDirectory } from "../../common/fs/ensure-dir.injectable";
@@ -30,7 +28,7 @@ import type { JoinPaths } from "../../common/path/join-paths.injectable";
 import type { GetBasenameOfPath } from "../../common/path/get-basename.injectable";
 import type { GetDirnameOfPath } from "../../common/path/get-dirname.injectable";
 import type { GetRelativePath } from "../../common/path/get-relative-path.injectable";
-import type { RemovePath } from "../../common/fs/remove-path.injectable";
+import type { RemovePath } from "../../common/fs/remove.injectable";
 import type TypedEventEmitter from "typed-emitter";
 
 interface Dependencies {
@@ -38,14 +36,13 @@ interface Dependencies {
   readonly extensionsStore: ExtensionsStore;
   readonly extensionInstallationStateStore: ExtensionInstallationStateStore;
   readonly extensionPackageRootDirectory: string;
-  readonly staticFilesDirectory: string;
+  readonly resourcesDirectory: string;
   readonly logger: Logger;
   readonly isProduction: boolean;
   readonly fileSystemSeparator: string;
   readonly homeDirectoryPath: string;
   isCompatibleExtension: (manifest: LensExtensionManifest) => boolean;
   installExtension: (name: string) => Promise<void>;
-  installExtensions: (packageJsonPath: string, packagesJson: PackageJson) => Promise<void>;
   readJsonFile: ReadJson;
   pathExists: PathExists;
   removePath: RemovePath;
@@ -137,14 +134,6 @@ export class ExtensionDiscovery {
     return this.dependencies.joinPaths(this.dependencies.extensionPackageRootDirectory, manifestFilename);
   }
 
-  get inTreeTargetPath(): string {
-    return this.dependencies.joinPaths(this.dependencies.extensionPackageRootDirectory, "extensions");
-  }
-
-  get inTreeFolderPath(): string {
-    return this.dependencies.joinPaths(this.dependencies.staticFilesDirectory, "../extensions");
-  }
-
   get nodeModulesPath(): string {
     return this.dependencies.joinPaths(this.dependencies.extensionPackageRootDirectory, "node_modules");
   }
@@ -329,26 +318,6 @@ export class ExtensionDiscovery {
     );
 
     await this.dependencies.removePath(this.dependencies.joinPaths(this.dependencies.extensionPackageRootDirectory, "package-lock.json"));
-
-    const canWriteToInTreeFolder = await this.dependencies.accessPath(this.inTreeFolderPath, constants.W_OK);
-
-    if (canWriteToInTreeFolder) {
-      // Set bundled folder path to static/extensions
-      this.bundledFolderPath = this.inTreeFolderPath;
-    } else {
-      // Remove e.g. /Users/<username>/Library/Application Support/LensDev/extensions
-      await this.dependencies.removePath(this.inTreeTargetPath);
-
-      // Create folder e.g. /Users/<username>/Library/Application Support/LensDev/extensions
-      await this.dependencies.ensureDirectory(this.inTreeTargetPath);
-
-      // Copy static/extensions to e.g. /Users/<username>/Library/Application Support/LensDev/extensions
-      await this.dependencies.copy(this.inTreeFolderPath, this.inTreeTargetPath);
-
-      // Set bundled folder path to e.g. /Users/<username>/Library/Application Support/LensDev/extensions
-      this.bundledFolderPath = this.inTreeTargetPath;
-    }
-
     await this.dependencies.ensureDirectory(this.nodeModulesPath);
     await this.dependencies.ensureDirectory(this.localFolderPath);
 
@@ -382,7 +351,7 @@ export class ExtensionDiscovery {
   protected async getByManifest(manifestPath: string, { isBundled = false } = {}): Promise<InstalledExtension | null> {
     try {
       const manifest = await this.dependencies.readJsonFile(manifestPath) as unknown as LensExtensionManifest;
-      const id = this.getInstalledManifestPath(manifest.name);
+      const id = isBundled ? manifestPath : this.getInstalledManifestPath(manifest.name);
       const isEnabled = this.dependencies.extensionsStore.isEnabled({ id, isBundled });
       const extensionDir = this.dependencies.getDirnameOfPath(manifestPath);
       const npmPackage = this.dependencies.joinPaths(extensionDir, `${manifest.name}-${manifest.version}.tgz`);
@@ -413,57 +382,16 @@ export class ExtensionDiscovery {
   }
 
   async ensureExtensions(): Promise<Map<LensExtensionId, InstalledExtension>> {
-    const bundledExtensions = await this.loadBundledExtensions();
-    const userExtensions = await this.loadFromFolder(this.localFolderPath, bundledExtensions.map((extension) => extension.manifest.name));
-    const extensions = bundledExtensions.concat(userExtensions);
+    const userExtensions = await this.loadFromFolder(this.localFolderPath);
 
-    await this.installBundledPackages(this.packageJsonPath, extensions);
-
-    return this.extensions = new Map(extensions.map(extension => [extension.id, extension]));
+    return this.extensions = new Map(userExtensions.map(extension => [extension.id, extension]));
   }
 
-  /**
-   * Write package.json to file system and install dependencies.
-   */
-  installBundledPackages(packageJsonPath: string, extensions: InstalledExtension[]): Promise<void> {
-    const dependencies = Object.fromEntries(
-      extensions.filter(extension => extension.isBundled).map(extension => [extension.manifest.name, extension.absolutePath]),
-    );
-    const optionalDependencies = Object.fromEntries(
-      extensions.filter(extension => !extension.isBundled).map(extension => [extension.manifest.name, extension.absolutePath]),
-    );
-
-    return this.dependencies.installExtensions(packageJsonPath, { dependencies, optionalDependencies });
-  }
-
-  async loadBundledExtensions(): Promise<InstalledExtension[]> {
-    const extensions: InstalledExtension[] = [];
-    const folderPath = this.bundledFolderPath;
-    const paths = await this.dependencies.readDirectory(folderPath);
-
-    for (const fileName of paths) {
-      const absPath = this.dependencies.joinPaths(folderPath, fileName);
-      const extension = await this.loadExtensionFromFolder(absPath, { isBundled: true });
-
-      if (extension) {
-        extensions.push(extension);
-      }
-    }
-    this.dependencies.logger.debug(`${logModule}: ${extensions.length} extensions loaded`, { folderPath, extensions });
-
-    return extensions;
-  }
-
-  async loadFromFolder(folderPath: string, bundledExtensions: string[]): Promise<InstalledExtension[]> {
+  async loadFromFolder(folderPath: string): Promise<InstalledExtension[]> {
     const extensions: InstalledExtension[] = [];
     const paths = await this.dependencies.readDirectory(folderPath);
 
     for (const fileName of paths) {
-      // do not allow to override bundled extensions
-      if (bundledExtensions.includes(fileName)) {
-        continue;
-      }
-
       const absPath = this.dependencies.joinPaths(folderPath, fileName);
 
       try {
