@@ -20,6 +20,7 @@ import type { IObservableValue } from "mobx";
 import { runInAction, computed, observable } from "mobx";
 import storageSaveDelayInjectable from "../../renderer/utils/create-storage/storage-save-delay.injectable";
 import type { DiContainer } from "@ogre-tools/injectable";
+import { flushPromises } from "../../common/test-utils/flush-promises";
 
 describe("cluster - sidebar and tab navigation for extensions", () => {
   let applicationBuilder: ApplicationBuilder;
@@ -399,6 +400,8 @@ describe("cluster - sidebar and tab navigation for extensions", () => {
 
             const readJsonFileFake = windowDi.inject(readJsonFileInjectable);
 
+            await flushPromises(); // Needed because of several async calls
+
             const actual = await readJsonFileFake(
               "/some-directory-for-lens-local-storage/some-cluster-id.json",
             );
