@@ -4,19 +4,15 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { asyncComputed } from "@ogre-tools/injectable-react";
-import callForPublicHelmRepositoriesInjectable from "./call-for-public-helm-repositories.injectable";
+import requestPublicHelmRepositoriesInjectable from "./request-public-helm-repositories.injectable";
 
 const publicHelmRepositoriesInjectable = getInjectable({
   id: "public-helm-repositories",
 
-  instantiate: (di) => {
-    const callForPublicHelmRepositories = di.inject(callForPublicHelmRepositoriesInjectable);
-
-    return asyncComputed({
-      getValueFromObservedPromise: callForPublicHelmRepositories,
-      valueWhenPending: [],
-    });
-  },
+  instantiate: (di) => asyncComputed({
+    getValueFromObservedPromise: di.inject(requestPublicHelmRepositoriesInjectable),
+    valueWhenPending: [],
+  }),
 });
 
 export default publicHelmRepositoriesInjectable;
