@@ -8,12 +8,13 @@ import { withInjectables } from "@ogre-tools/injectable-react";
 import type { UserStore } from "../../../../../../common/user-store";
 import userStoreInjectable from "../../../../../../common/user-store/user-store.injectable";
 import { Select } from "../../../../../../renderer/components/select";
-import { defaultLocaleTimezone } from "../../../../../../common/user-store/preferences-helpers";
 import moment from "moment-timezone";
 import { observer } from "mobx-react";
+import currentTimezoneInjectable from "../../../../../../common/user-store/current-timezone.injectable";
 
 interface Dependencies {
   userStore: UserStore;
+  currentTimezone: string;
 }
 
 const timezoneOptions = moment.tz.names()
@@ -23,26 +24,26 @@ const timezoneOptions = moment.tz.names()
   }));
 
 
-const NonInjectedTimezone = observer(({ userStore }: Dependencies) => (
+const NonInjectedTimezone = observer(({
+  userStore,
+  currentTimezone,
+}: Dependencies) => (
   <section id="locale">
     <SubTitle title="Locale Timezone" />
     <Select
       id="timezone-input"
       options={timezoneOptions}
       value={userStore.localeTimezone}
-      onChange={value => userStore.localeTimezone = value?.value ?? defaultLocaleTimezone}
+      onChange={value => userStore.localeTimezone = value?.value ?? currentTimezone}
       themeName="lens"
     />
   </section>
 
 ));
 
-export const Timezone = withInjectables<Dependencies>(
-  NonInjectedTimezone,
-
-  {
-    getProps: (di) => ({
-      userStore: di.inject(userStoreInjectable),
-    }),
-  },
-);
+export const Timezone = withInjectables<Dependencies>(NonInjectedTimezone, {
+  getProps: (di) => ({
+    userStore: di.inject(userStoreInjectable),
+    currentTimezone: di.inject(currentTimezoneInjectable),
+  }),
+});
