@@ -3,7 +3,6 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { Tab } from "../../../../renderer/components/tabs";
-import navigateToPreferenceTabInjectable from "./navigate-to-preference-tab/navigate-to-preference-tab.injectable";
 import { withInjectables } from "@ogre-tools/injectable-react";
 import { observer } from "mobx-react";
 import type { PreferenceTab } from "../preference-items/preference-item-injection-token";
@@ -12,7 +11,6 @@ import preferenceTabIsActiveInjectable from "./navigate-to-preference-tab/prefer
 import React from "react";
 
 interface Dependencies {
-  navigateToTab: (tabId: string) => void;
   tabIsActive: IComputedValue<boolean>;
 }
 
@@ -20,23 +18,21 @@ interface PreferenceNavigationTabProps {
   tab: PreferenceTab;
 }
 
-const NonInjectedPreferencesNavigationTab = observer(({ navigateToTab, tabIsActive, tab } : Dependencies & PreferenceNavigationTabProps) => (
+const NonInjectedPreferencesNavigationTab = observer(({
+  tabIsActive,
+  tab,
+}: Dependencies & PreferenceNavigationTabProps) => (
   <Tab
-    onClick={() => navigateToTab(tab.pathId)}
     active={tabIsActive.get()}
     label={tab.label}
     data-preference-tab-link-test={tab.pathId}
+    value={tab.pathId}
   />
 ));
 
-export const PreferencesNavigationTab = withInjectables<Dependencies, PreferenceNavigationTabProps>(
-  NonInjectedPreferencesNavigationTab,
-
-  {
-    getProps: (di, props) => ({
-      navigateToTab: di.inject(navigateToPreferenceTabInjectable),
-      tabIsActive: di.inject(preferenceTabIsActiveInjectable, props.tab.pathId),
-      ...props,
-    }),
-  },
-);
+export const PreferencesNavigationTab = withInjectables<Dependencies, PreferenceNavigationTabProps>(NonInjectedPreferencesNavigationTab, {
+  getProps: (di, props) => ({
+    ...props,
+    tabIsActive: di.inject(preferenceTabIsActiveInjectable, props.tab.pathId),
+  }),
+});
