@@ -5,24 +5,21 @@
 
 import type { RequestPromiseOptions } from "request-promise-native";
 import type { Cluster } from "../../common/cluster/cluster";
-import { k8sRequest } from "../k8s-request";
+import type { K8sRequest } from "../k8s-request.injectable";
 
 export interface ClusterDetectionResult {
   value: string | number | boolean;
   accuracy: number;
 }
 
-export class BaseClusterDetector {
-  key: string;
+export abstract class BaseClusterDetector {
+  abstract readonly key: string;
 
-  constructor(public cluster: Cluster) {
-  }
+  constructor(public readonly cluster: Cluster, private _k8sRequest: K8sRequest) {}
 
-  detect(): Promise<ClusterDetectionResult> {
-    return null;
-  }
+  abstract detect(): Promise<ClusterDetectionResult | null>;
 
   protected async k8sRequest<T = any>(path: string, options: RequestPromiseOptions = {}): Promise<T> {
-    return k8sRequest(this.cluster, path, options);
+    return this._k8sRequest(this.cluster, path, options);
   }
 }
