@@ -5,73 +5,54 @@
 import type { IpcMainInvokeEvent } from "electron";
 import { BrowserWindow, Menu } from "electron";
 import { clusterFrameMap } from "../../../../common/cluster-frames";
-import { clusterActivateHandler, clusterSetFrameIdHandler, clusterRefreshHandler, clusterDisconnectHandler, clusterKubectlApplyAllHandler, clusterKubectlDeleteAllHandler } from "../../../../common/ipc/cluster";
+import { clusterActivateHandler, clusterSetFrameIdHandler, clusterDisconnectHandler, clusterStates } from "../../../../common/ipc/cluster";
 import type { ClusterId } from "../../../../common/cluster-types";
-import { ClusterStore } from "../../../../common/cluster-store/cluster-store";
+import type { ClusterStore } from "../../../../common/cluster-store/cluster-store";
 import { broadcastMainChannel, broadcastMessage, ipcMainHandle, ipcMainOn } from "../../../../common/ipc";
 import type { CatalogEntityRegistry } from "../../../catalog";
 import { pushCatalogToRenderer } from "../../../catalog-pusher";
-import type { ClusterManager } from "../../../cluster/manager";
 import type { IComputedValue } from "mobx";
 import { windowActionHandleChannel, windowLocationChangedChannel, windowOpenAppMenuAsContextMenuChannel } from "../../../../common/ipc/window";
 import { handleWindowAction, onLocationChange } from "../../../ipc/window";
-import { openFilePickingDialogChannel } from "../../../../common/ipc/dialog";
-import { getNativeThemeChannel } from "../../../../common/ipc/native-theme";
-import type { Theme } from "../../../theme/operating-system-theme-state.injectable";
-import type { AskUserForFilePaths } from "../../../ipc/ask-user-for-file-paths.injectable";
 import type { ApplicationMenuItemTypes } from "../../../../features/application-menu/main/menu-items/application-menu-item-injection-token";
 import type { Composite } from "../../../../common/utils/composite/get-composite/get-composite";
 import { getApplicationMenuTemplate } from "../../../../features/application-menu/main/populate-application-menu.injectable";
 import type { MenuItemRoot } from "../../../../features/application-menu/main/application-menu-item-composite.injectable";
 import type { EmitAppEvent } from "../../../../common/app-event-bus/emit-event.injectable";
-import type { CreateResourceApplier } from "../../../resource-applier/create-resource-applier.injectable";
-
+import type { GetClusterById } from "../../../../common/cluster-store/get-by-id.injectable";
 interface Dependencies {
   applicationMenuItemComposite: IComputedValue<Composite<ApplicationMenuItemTypes | MenuItemRoot>>;
-  clusterManager: ClusterManager;
   catalogEntityRegistry: CatalogEntityRegistry;
   clusterStore: ClusterStore;
-  operatingSystemTheme: IComputedValue<Theme>;
-  askUserForFilePaths: AskUserForFilePaths;
   emitAppEvent: EmitAppEvent;
-  createResourceApplier: CreateResourceApplier;
+  getClusterById: GetClusterById;
 }
 
 export const setupIpcMainHandlers = ({
   applicationMenuItemComposite,
   catalogEntityRegistry,
   clusterStore,
-  operatingSystemTheme,
-  askUserForFilePaths,
   emitAppEvent,
-  createResourceApplier,
+  getClusterById,
 }: Dependencies) => {
   ipcMainHandle(clusterActivateHandler, (event, clusterId: ClusterId, force = false) => {
-    return ClusterStore.getInstance()
-      .getById(clusterId)
+    return getClusterById(clusterId)
       ?.activate(force);
   });
 
   ipcMainHandle(clusterSetFrameIdHandler, (event: IpcMainInvokeEvent, clusterId: ClusterId) => {
-    const cluster = ClusterStore.getInstance().getById(clusterId);
+    const cluster = getClusterById(clusterId);
 
     if (cluster) {
       clusterFrameMap.set(cluster.id, { frameId: event.frameId, processId: event.processId });
-      cluster.pushState();
 
       pushCatalogToRenderer(catalogEntityRegistry);
     }
   });
 
-  ipcMainHandle(clusterRefreshHandler, (event, clusterId: ClusterId) => {
-    return ClusterStore.getInstance()
-      .getById(clusterId)
-      ?.refresh({ refreshMetadata: true });
-  });
-
   ipcMainHandle(clusterDisconnectHandler, (event, clusterId: ClusterId) => {
     emitAppEvent({ name: "cluster", action: "stop" });
-    const cluster = ClusterStore.getInstance().getById(clusterId);
+    const cluster = getClusterById(clusterId);
 
     if (cluster) {
       cluster.disconnect();
@@ -79,50 +60,10 @@ export const setupIpcMainHandlers = ({
     }
   });
 
-  ipcMainHandle(clusterKubectlApplyAllHandler, async (event, clusterId: ClusterId, resources: string[], extraArgs: string[]) => {
-    emitAppEvent({ name: "cluster", action: "kubectl-apply-all" });
-    const cluster = ClusterStore.getInstance().getById(clusterId);
-
-    if (cluster) {
-      const applier = createResourceApplier(cluster);
-
-      try {
-        const stdout = await applier.kubectlApplyAll(resources, extraArgs);
-
-        return { stdout };
-      } catch (error: any) {
-        return { stderr: error };
-      }
-    } else {
-      throw `${clusterId} is not a valid cluster id`;
-    }
-  });
-
-  ipcMainHandle(clusterKubectlDeleteAllHandler, async (event, clusterId: ClusterId, resources: string[], extraArgs: string[]) => {
-    emitAppEvent({ name: "cluster", action: "kubectl-delete-all" });
-    const cluster = ClusterStore.getInstance().getById(clusterId);
-
-    if (cluster) {
-      const applier = createResourceApplier(cluster);
-
-      try {
-        const stdout = await applier.kubectlDeleteAll(resources, extraArgs);
-
-        return { stdout };
-      } catch (error: any) {
-        return { stderr: error };
-      }
-    } else {
-      throw `${clusterId} is not a valid cluster id`;
-    }
-  });
-
   ipcMainHandle(windowActionHandleChannel, (event, action) => handleWindowAction(action));
 
   ipcMainOn(windowLocationChangedChannel, () => onLocationChange());
 
-  ipcMainHandle(openFilePickingDialogChannel, (event, opts) => askUserForFilePaths(opts));
-
   ipcMainHandle(broadcastMainChannel, (event, channel, ...args) => broadcastMessage(channel, ...args));
 
   ipcMainOn(windowOpenAppMenuAsContextMenuChannel, async (event) => {
@@ -137,9 +78,10 @@ export const setupIpcMainHandlers = ({
     });
   });
 
-  ipcMainHandle(getNativeThemeChannel, () => {
-    return operatingSystemTheme.get();
-  });
-
-  clusterStore.provideInitialFromMain();
+  ipcMainHandle(clusterStates, () => (
+    clusterStore.clustersList.map(cluster => ({
+      id: cluster.id,
+      state: cluster.getState(),
+    }))
+  ));
 };
