@@ -78,10 +78,10 @@ const getActiveHelmRepositoriesInjectable = getInjectable({
       const updateResult = await execHelm(["repo", "update"]);
 
       if (!updateResult.callWasSuccessful) {
-        if (!updateResult.error.includes(internalHelmErrorForNoRepositoriesFound)) {
+        if (!updateResult.error.stderr.includes(internalHelmErrorForNoRepositoriesFound)) {
           return {
             callWasSuccessful: false,
-            error: `Error updating Helm repositories: ${updateResult.error}`,
+            error: `Error updating Helm repositories: ${updateResult.error.stderr}`,
           };
         }
         const resultOfAddingDefaultRepository = await execHelm(["repo", "add", "bitnami", "https://charts.bitnami.com/bitnami"]);
@@ -89,7 +89,7 @@ const getActiveHelmRepositoriesInjectable = getInjectable({
         if (!resultOfAddingDefaultRepository.callWasSuccessful) {
           return {
             callWasSuccessful: false,
-            error: `Error when adding default Helm repository: ${resultOfAddingDefaultRepository.error}`,
+            error: `Error when adding default Helm repository: ${resultOfAddingDefaultRepository.error.stderr}`,
           };
         }
       }
