@@ -6,14 +6,11 @@ import { getInjectable } from "@ogre-tools/injectable";
 import type { KubeAuthProxyDependencies } from "./kube-auth-proxy";
 import { KubeAuthProxy } from "./kube-auth-proxy";
 import type { Cluster } from "../../common/cluster/cluster";
-import selfsigned from "selfsigned";
-import { getBinaryName } from "../../common/vars";
 import spawnInjectable from "../child-process/spawn.injectable";
-import { getKubeAuthProxyCertificate } from "./get-kube-auth-proxy-certificate";
+import kubeAuthProxyCertificateInjectable from "./kube-auth-proxy-certificate.injectable";
 import loggerInjectable from "../../common/logger.injectable";
-import baseBundledBinariesDirectoryInjectable from "../../common/vars/base-bundled-binaries-dir.injectable";
 import waitUntilPortIsUsedInjectable from "./wait-until-port-is-used/wait-until-port-is-used.injectable";
-import joinPathsInjectable from "../../common/path/join-paths.injectable";
+import lensK8sProxyPathInjectable from "./lens-k8s-proxy-path.injectable";
 
 export type CreateKubeAuthProxy = (cluster: Cluster, environmentVariables: NodeJS.ProcessEnv) => KubeAuthProxy;
 
@@ -21,20 +18,20 @@ const createKubeAuthProxyInjectable = getInjectable({
   id: "create-kube-auth-proxy",
 
   instantiate: (di): CreateKubeAuthProxy => {
-    const binaryName = getBinaryName("lens-k8s-proxy");
-    const joinPaths = di.inject(joinPathsInjectable);
+    const dependencies: Omit<KubeAuthProxyDependencies, "proxyCert"> = {
+      proxyBinPath: di.inject(lensK8sProxyPathInjectable),
+      spawn: di.inject(spawnInjectable),
+      logger: di.inject(loggerInjectable),
+      waitUntilPortIsUsed: di.inject(waitUntilPortIsUsedInjectable),
+    };
 
     return (cluster: Cluster, environmentVariables: NodeJS.ProcessEnv) => {
       const clusterUrl = new URL(cluster.apiUrl);
-      const dependencies: KubeAuthProxyDependencies = {
-        proxyBinPath: joinPaths(di.inject(baseBundledBinariesDirectoryInjectable), binaryName),
-        proxyCert: getKubeAuthProxyCertificate(clusterUrl.hostname, selfsigned.generate),
-        spawn: di.inject(spawnInjectable),
-        logger: di.inject(loggerInjectable),
-        waitUntilPortIsUsed: di.inject(waitUntilPortIsUsedInjectable),
-      };
 
-      return new KubeAuthProxy(dependencies, cluster, environmentVariables);
+      return new KubeAuthProxy({
+        ...dependencies,
+        proxyCert: di.inject(kubeAuthProxyCertificateInjectable, clusterUrl.hostname),
+      }, cluster, environmentVariables);
     };
   },
 });
