@@ -8,6 +8,8 @@ import clusterFramesInjectable from "../../../common/cluster-frames.injectable";
 import showApplicationWindowInjectable from "./show-application-window.injectable";
 import getCurrentApplicationWindowInjectable from "./application-window/get-current-application-window.injectable";
 import assert from "assert";
+import type { NavigateForExtensionArgs } from "../../../features/extensions/navigate/common/channel";
+import { navigateForExtensionChannel } from "../../../features/extensions/navigate/common/channel";
 
 export type NavigateForExtension = (
   extId: string,
@@ -42,9 +44,9 @@ const navigateForExtensionInjectable = getInjectable({
       );
 
       applicationWindow.send({
-        channel: "extension:navigate",
+        channel: navigateForExtensionChannel.id,
         frameInfo,
-        data: [extId, pageId, params],
+        data: { extId, pageId, params } as NavigateForExtensionArgs,
       });
     };
   },
