@@ -4,28 +4,25 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import appPathsStateInjectable from "../../common/app-paths/app-paths-state.injectable";
-import { beforeFrameStartsInjectionToken } from "../before-frame-starts/before-frame-starts-injection-token";
+import { beforeFrameStartsFirstInjectionToken } from "../before-frame-starts/tokens";
 import { appPathsChannel } from "../../common/app-paths/app-paths-channel";
 import { requestFromChannelInjectionToken } from "../../common/utils/channel/request-from-channel-injection-token";
 
 const setupAppPathsInjectable = getInjectable({
   id: "setup-app-paths",
 
-  instantiate: (di) => {
-    const requestFromChannel = di.inject(requestFromChannelInjectionToken);
-    const appPathsState = di.inject(appPathsStateInjectable);
+  instantiate: (di) => ({
+    id: "setup-app-paths",
+    run: async () => {
+      const requestFromChannel = di.inject(requestFromChannelInjectionToken);
+      const appPathsState = di.inject(appPathsStateInjectable);
+      const appPaths = await requestFromChannel(appPathsChannel);
 
-    return {
-      id: "setup-app-paths",
-      run: async () => {
-        const appPaths = await requestFromChannel(appPathsChannel);
+      appPathsState.set(appPaths);
+    },
+  }),
 
-        appPathsState.set(appPaths);
-      },
-    };
-  },
-
-  injectionToken: beforeFrameStartsInjectionToken,
+  injectionToken: beforeFrameStartsFirstInjectionToken,
 });
 
 export default setupAppPathsInjectable;
