@@ -10,7 +10,6 @@ import { Catalog } from "./catalog";
 import type { CatalogEntityActionContext, CatalogEntityData } from "../../../common/catalog";
 import { CatalogEntity } from "../../../common/catalog";
 import type { CatalogEntityOnBeforeRun, CatalogEntityRegistry } from "../../api/catalog/entity/registry";
-import { CatalogEntityDetailRegistry } from "../../../extensions/registries";
 import type { CatalogEntityStore } from "./catalog-entity-store/catalog-entity.store";
 import { getDiForUnitTesting } from "../../getDiForUnitTesting";
 import type { DiContainer } from "@ogre-tools/injectable";
@@ -27,6 +26,10 @@ import broadcastMessageInjectable from "../../../common/ipc/broadcast-message.in
 import type { AsyncFnMock } from "@async-fn/jest";
 import asyncFn from "@async-fn/jest";
 import { flushPromises } from "../../../common/test-utils/flush-promises";
+import userStoreInjectable from "../../../common/user-store/user-store.injectable";
+import releaseChannelInjectable from "../../../common/vars/release-channel.injectable";
+import defaultUpdateChannelInjectable from "../../../features/application-update/common/selected-update-channel/default-update-channel.injectable";
+import currentlyInClusterFrameInjectable from "../../routes/currently-in-cluster-frame.injectable";
 
 class MockCatalogEntity extends CatalogEntity {
   public apiVersion = "api";
@@ -62,17 +65,15 @@ describe("<Catalog />", () => {
   let catalogEntityItem: MockCatalogEntity;
   let render: DiRender;
 
-  beforeEach(() => {
+  beforeEach(async () => {
     di = getDiForUnitTesting({ doGeneralOverrides: true });
 
     di.override(directoryForUserDataInjectable, () => "some-directory-for-user-data");
-
+    di.override(currentlyInClusterFrameInjectable, () => false);
     di.override(broadcastMessageInjectable, () => async () => {});
 
     di.permitSideEffects(getConfigurationFileModelInjectable);
 
-    CatalogEntityDetailRegistry.createInstance();
-
     render = renderFor(di);
     onRun = jest.fn();
     catalogEntityItem = createMockCatalogEntity(onRun);
@@ -85,10 +86,13 @@ describe("<Catalog />", () => {
     Object.assign(catalogEntityStore, {
       selectedItem: computed(() => catalogEntityItem),
     });
-  });
 
-  afterEach(() => {
-    CatalogEntityDetailRegistry.resetInstance();
+    di.override(releaseChannelInjectable, () => ({
+      get: () => "latest" as const,
+      init: async () => {},
+    }));
+    await di.inject(defaultUpdateChannelInjectable).init();
+    di.inject(userStoreInjectable).load();
   });
 
   describe("can use catalogEntityRegistry.addOnBeforeRun to add hooks for catalog entities", () => {
