@@ -6,6 +6,7 @@ import { getInjectable } from "@ogre-tools/injectable";
 import assert from "assert";
 import { kubeObjectStoreInjectionToken } from "../../../common/k8s-api/api-manager/manager.injectable";
 import secretApiInjectable from "../../../common/k8s-api/endpoints/secret.api.injectable";
+import clusterFrameContextForNamespacedResourcesInjectable from "../../cluster-frame-context/for-namespaced-resources.injectable";
 import storesAndApisCanBeCreatedInjectable from "../../stores-apis-can-be-created.injectable";
 import { SecretStore } from "./store";
 
@@ -16,7 +17,9 @@ const secretStoreInjectable = getInjectable({
 
     const api = di.inject(secretApiInjectable);
 
-    return new SecretStore(api);
+    return new SecretStore({
+      context: di.inject(clusterFrameContextForNamespacedResourcesInjectable),
+    }, api);
   },
   injectionToken: kubeObjectStoreInjectionToken,
 });
