@@ -7,6 +7,7 @@ import assert from "assert";
 import autoRegistrationEmitterInjectable from "../../../common/k8s-api/api-manager/auto-registration-emitter.injectable";
 import { kubeObjectStoreInjectionToken } from "../../../common/k8s-api/api-manager/manager.injectable";
 import customResourceDefinitionApiInjectable from "../../../common/k8s-api/endpoints/custom-resource-definition.api.injectable";
+import clusterFrameContextForClusterScopedResourcesInjectable from "../../cluster-frame-context/for-cluster-scoped-resources.injectable";
 import storesAndApisCanBeCreatedInjectable from "../../stores-apis-can-be-created.injectable";
 import { CustomResourceDefinitionStore } from "./definition.store";
 
@@ -19,6 +20,7 @@ const customResourceDefinitionStoreInjectable = getInjectable({
 
     return new CustomResourceDefinitionStore({
       autoRegistration: di.inject(autoRegistrationEmitterInjectable),
+      context: di.inject(clusterFrameContextForClusterScopedResourcesInjectable),
     }, api);
   },
   injectionToken: kubeObjectStoreInjectionToken,
