@@ -6,6 +6,7 @@ import { getInjectable } from "@ogre-tools/injectable";
 import assert from "assert";
 import { kubeObjectStoreInjectionToken } from "../../../common/k8s-api/api-manager/manager.injectable";
 import endpointsApiInjectable from "../../../common/k8s-api/endpoints/endpoint.api.injectable";
+import clusterFrameContextForNamespacedResourcesInjectable from "../../cluster-frame-context/for-namespaced-resources.injectable";
 import storesAndApisCanBeCreatedInjectable from "../../stores-apis-can-be-created.injectable";
 import { EndpointsStore } from "./store";
 
@@ -16,7 +17,9 @@ const endpointsStoreInjectable = getInjectable({
 
     const api = di.inject(endpointsApiInjectable);
 
-    return new EndpointsStore(api);
+    return new EndpointsStore({
+      context: di.inject(clusterFrameContextForNamespacedResourcesInjectable),
+    }, api);
   },
   injectionToken: kubeObjectStoreInjectionToken,
 });
