@@ -7,6 +7,7 @@ import assert from "assert";
 import getPersistentVolumesByStorageClassInjectable from "../+storage-volumes/get-persisten-volumes-by-storage-class.injectable";
 import { kubeObjectStoreInjectionToken } from "../../../common/k8s-api/api-manager/manager.injectable";
 import storageClassApiInjectable from "../../../common/k8s-api/endpoints/storage-class.api.injectable";
+import clusterFrameContextForClusterScopedResourcesInjectable from "../../cluster-frame-context/for-cluster-scoped-resources.injectable";
 import storesAndApisCanBeCreatedInjectable from "../../stores-apis-can-be-created.injectable";
 import { StorageClassStore } from "./store";
 
@@ -19,6 +20,7 @@ const storageClassStoreInjectable = getInjectable({
 
     return new StorageClassStore({
       getPersistentVolumesByStorageClass: di.inject(getPersistentVolumesByStorageClassInjectable),
+      context: di.inject(clusterFrameContextForClusterScopedResourcesInjectable),
     }, api);
   },
   injectionToken: kubeObjectStoreInjectionToken,
