@@ -3,18 +3,18 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import type { KubeObjectStoreOptions } from "../../../common/k8s-api/kube-object.store";
+import type { KubeObjectStoreDependencies, KubeObjectStoreOptions } from "../../../common/k8s-api/kube-object.store";
 import { KubeObjectStore } from "../../../common/k8s-api/kube-object.store";
 import type { CronJob, CronJobApi } from "../../../common/k8s-api/endpoints/cron-job.api";
 import type { GetJobsByOwner } from "../+workloads-jobs/get-jobs-by-owner.injectable";
 
-interface Dependencies {
+interface Dependencies extends KubeObjectStoreDependencies {
   getJobsByOwner: GetJobsByOwner;
 }
 
 export class CronJobStore extends KubeObjectStore<CronJob, CronJobApi> {
   constructor(protected readonly dependencies: Dependencies, api: CronJobApi, opts?: KubeObjectStoreOptions) {
-    super(api, opts);
+    super(dependencies, api, opts);
   }
 
   getStatuses(cronJobs?: CronJob[]) {
