@@ -4,10 +4,11 @@
  */
 import { getInjectionToken } from "@ogre-tools/injectable";
 import type { IComputedValue } from "mobx";
+import type { KubeApiResourceDescriptor } from "../../../../common/rbac";
 import type { WorkloadStatus } from "../overview-workload-status";
 
 export interface Workload {
-  resourceName: string;
+  resource: KubeApiResourceDescriptor;
   open: () => void;
   amountOfItems: IComputedValue<number>;
   status: IComputedValue<WorkloadStatus>;
