@@ -9,6 +9,7 @@ import storesAndApisCanBeCreatedInjectable from "../../stores-apis-can-be-create
 import { kubeObjectStoreInjectionToken } from "../../../common/k8s-api/api-manager/manager.injectable";
 import { PodStore } from "./store";
 import podMetricsApiInjectable from "../../../common/k8s-api/endpoints/pod-metrics.api.injectable";
+import clusterFrameContextForNamespacedResourcesInjectable from "../../cluster-frame-context/for-namespaced-resources.injectable";
 
 const podStoreInjectable = getInjectable({
   id: "pod-store",
@@ -19,6 +20,7 @@ const podStoreInjectable = getInjectable({
 
     return new PodStore({
       podMetricsApi: di.inject(podMetricsApiInjectable),
+      context: di.inject(clusterFrameContextForNamespacedResourcesInjectable),
     }, api);
   },
   injectionToken: kubeObjectStoreInjectionToken,
