@@ -6,9 +6,8 @@ import { getInjectable } from "@ogre-tools/injectable";
 
 import { computed } from "mobx";
 import { computedInjectManyInjectable } from "@ogre-tools/injectable-extension-for-mobx";
-import { filter, map, sortBy } from "lodash/fp";
-import { pipeline } from "@ogre-tools/fp";
 import { kubeObjectDetailItemInjectionToken } from "./kube-object-detail-item-injection-token";
+import { byValue } from "../../../../common/utils/sort-function";
 
 const kubeObjectDetailItemsInjectable = getInjectable({
   id: "kube-object-detail-items",
@@ -17,14 +16,12 @@ const kubeObjectDetailItemsInjectable = getInjectable({
     const computedInjectMany = di.inject(computedInjectManyInjectable);
     const items = computedInjectMany(kubeObjectDetailItemInjectionToken);
 
-    return computed(() => {
-      return pipeline(
-        items.get(),
-        filter((item) => item.enabled.get()),
-        sortBy((item) => item.orderNumber),
-        map((item) => item.Component),
-      );
-    });
+    return computed(() => (
+      items.get()
+        .filter(item => item.enabled.get())
+        .sort(byValue(item => item.orderNumber))
+        .map(item => item.Component)
+    ));
   },
 });
 
