@@ -3,9 +3,9 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
+import apiBaseInjectable from "../../../common/k8s-api/api-base.injectable";
 import type { ServiceAccount } from "../../../common/k8s-api/endpoints";
 import { urlBuilderFor } from "../../../common/utils/buildUrl";
-import apiBaseInjectable from "../../k8s/api-base.injectable";
 import openKubeconfigDialogInjectable from "./open.injectable";
 
 export type OpenServiceAccountKubeConfigDialog = (account: ServiceAccount) => void;
