@@ -5,6 +5,7 @@
 
 import "./sub-title.scss";
 import React from "react";
+import type { SingleOrMany } from "../../utils";
 import { cssNames } from "../../utils";
 
 export interface SubTitleProps {
@@ -12,6 +13,7 @@ export interface SubTitleProps {
   title: React.ReactNode;
   compact?: boolean; // no bottom padding
   id?: string;
+  children?: SingleOrMany<React.ReactNode>;
 }
 
 export class SubTitle extends React.Component<SubTitleProps> {
@@ -23,7 +25,9 @@ export class SubTitle extends React.Component<SubTitleProps> {
 
     return (
       <div className={classNames} id={id}>
-        {title} {children}
+        {title}
+        {" "}
+        {children}
       </div>
     );
   }
