@@ -9,10 +9,10 @@ import type { IComputedValue, ObservableMap } from "mobx";
 import { action, computed, observable, runInAction } from "mobx";
 import React from "react";
 import { Router } from "react-router";
-import allowedResourcesInjectable from "../../cluster-frame-context/allowed-resources.injectable";
 import type { RenderResult } from "@testing-library/react";
 import { fireEvent, queryByText } from "@testing-library/react";
-import type { KubeResource } from "../../../common/rbac";
+import type { KubeApiResourceDescriptor } from "../../../common/rbac";
+import { formatKubeApiResource } from "../../../common/rbac";
 import type { DiContainer, Injectable } from "@ogre-tools/injectable";
 import { getInjectable } from "@ogre-tools/injectable";
 import mainExtensionsInjectable from "../../../extensions/main-extensions.injectable";
@@ -22,10 +22,7 @@ import navigateToPreferencesInjectable from "../../../features/preferences/commo
 import type { NavigateToHelmCharts } from "../../../common/front-end-routing/routes/cluster/helm/charts/navigate-to-helm-charts.injectable";
 import navigateToHelmChartsInjectable from "../../../common/front-end-routing/routes/cluster/helm/charts/navigate-to-helm-charts.injectable";
 import hostedClusterInjectable from "../../cluster-frame-context/hosted-cluster.injectable";
-import { ClusterFrameContext } from "../../cluster-frame-context/cluster-frame-context";
 import type { Cluster } from "../../../common/cluster/cluster";
-import { KubeObjectStore } from "../../../common/k8s-api/kube-object.store";
-import clusterFrameContextInjectable from "../../cluster-frame-context/cluster-frame-context.injectable";
 import startMainApplicationInjectable from "../../../main/start-main-application/start-main-application.injectable";
 import startFrameInjectable from "../../start-frame/start-frame.injectable";
 import type { NamespaceStore } from "../+namespaces/store";
@@ -52,7 +49,6 @@ import hostedClusterIdInjectable from "../../cluster-frame-context/hosted-cluste
 import activeKubernetesClusterInjectable from "../../cluster-frame-context/active-kubernetes-cluster.injectable";
 import { catalogEntityFromCluster } from "../../../main/cluster/manager";
 import namespaceStoreInjectable from "../+namespaces/store.injectable";
-import { isAllowedResource } from "../../../common/cluster/is-allowed-resource";
 import createApplicationWindowInjectable from "../../../main/start-main-application/lens-window/application-window/create-application-window.injectable";
 import type { CreateElectronWindow } from "../../../main/start-main-application/lens-window/application-window/create-electron-window.injectable";
 import createElectronWindowInjectable from "../../../main/start-main-application/lens-window/application-window/create-electron-window.injectable";
@@ -63,12 +59,15 @@ import type { FakeExtensionOptions } from "./get-extension-fake";
 import { getExtensionFakeForMain, getExtensionFakeForRenderer } from "./get-extension-fake";
 import namespaceApiInjectable from "../../../common/k8s-api/endpoints/namespace.api.injectable";
 import { Namespace } from "../../../common/k8s-api/endpoints";
-import { overrideFsWithFakes } from "../../../test-utils/override-fs-with-fakes";
+import { getOverrideFsWithFakes } from "../../../test-utils/override-fs-with-fakes";
 import applicationMenuItemCompositeInjectable from "../../../features/application-menu/main/application-menu-item-composite.injectable";
 import { getCompositePaths } from "../../../common/utils/composite/get-composite-paths/get-composite-paths";
 import { discoverFor } from "./discovery-of-html-elements";
 import { findComposite } from "../../../common/utils/composite/find-composite/find-composite";
 import shouldStartHiddenInjectable from "../../../main/electron-app/features/should-start-hidden.injectable";
+import fsInjectable from "../../../common/fs/fs.injectable";
+import joinPathsInjectable from "../../../common/path/join-paths.injectable";
+import homeDirectoryPathInjectable from "../../../common/os/home-directory-path.injectable";
 
 type Callback = (di: DiContainer) => void | Promise<void>;
 
@@ -112,8 +111,9 @@ export interface ApplicationBuilder {
     create: (id: string) => LensWindowWithHelpers;
   };
 
-  allowKubeResource: (resourceName: KubeResource) => ApplicationBuilder;
+  allowKubeResource: (resource: KubeApiResourceDescriptor) => ApplicationBuilder;
   beforeApplicationStart: (callback: Callback) => ApplicationBuilder;
+  afterApplicationStart: (callback: Callback) => ApplicationBuilder;
   beforeWindowStart: (callback: Callback) => ApplicationBuilder;
   afterWindowStart: (callback: Callback) => ApplicationBuilder;
 
@@ -170,12 +170,22 @@ export const getApplicationBuilder = () => {
   const { overrideForWindow, sendToWindow } = overrideChannels(mainDi);
 
   const beforeApplicationStartCallbacks: Callback[] = [];
+  const afterApplicationStartCallbacks: Callback[] = [];
   const beforeWindowStartCallbacks: Callback[] = [];
   const afterWindowStartCallbacks: Callback[] = [];
 
-  const fsState = new Map();
+  const overrideFsWithFakes = getOverrideFsWithFakes();
 
-  overrideFsWithFakes(mainDi, fsState);
+  overrideFsWithFakes(mainDi);
+
+  // Set up ~/.kube as existing as a folder
+  {
+    const { ensureDirSync } = mainDi.inject(fsInjectable);
+    const joinPaths = mainDi.inject(joinPathsInjectable);
+    const homeDirectoryPath = mainDi.inject(homeDirectoryPathInjectable);
+
+    ensureDirSync(joinPaths(homeDirectoryPath, ".kube"));
+  }
 
   let environment = environments.application;
 
@@ -200,7 +210,7 @@ export const getApplicationBuilder = () => {
     },
   }));
 
-  const allowedResourcesState = observable.array<KubeResource>();
+  const allowedResourcesState = observable.set<string>();
 
   const windowHelpers = new Map<string, { di: DiContainer; getRendered: () => RenderResult }>();
 
@@ -210,7 +220,7 @@ export const getApplicationBuilder = () => {
     const windowDi = getRendererDi({ doGeneralOverrides: true });
 
     overrideForWindow(windowDi, windowId);
-    overrideFsWithFakes(windowDi, fsState);
+    overrideFsWithFakes(windowDi);
 
     runInAction(() => {
       windowDi.register(rendererExtensionsStateInjectable);
@@ -276,6 +286,24 @@ export const getApplicationBuilder = () => {
   const namespaces = observable.set<string>();
   const namespaceItems = observable.array<Namespace>();
   const selectedNamespaces = observable.set<string>();
+  const startMainApplication = mainDi.inject(startMainApplicationInjectable);
+
+  const startApplication = async ({ shouldStartHidden }: { shouldStartHidden: boolean }) => {
+    mainDi.inject(lensProxyPortInjectable).set(42);
+
+    for (const callback of beforeApplicationStartCallbacks) {
+      await callback(mainDi);
+    }
+
+    mainDi.override(shouldStartHiddenInjectable, () => shouldStartHidden);
+    await startMainApplication();
+
+    for (const callback of afterApplicationStartCallbacks) {
+      await callback(mainDi);
+    }
+
+    applicationHasStarted = true;
+  };
 
   const builder: ApplicationBuilder = {
     mainDi,
@@ -470,15 +498,11 @@ export const getApplicationBuilder = () => {
       environment = environments.clusterFrame;
 
       builder.beforeWindowStart((windowDi) => {
-        windowDi.override(allowedResourcesInjectable, () =>
-          computed(() => new Set([...allowedResourcesState])),
-        );
-
         const clusterStub = {
           id: "some-cluster-id",
-          accessibleNamespaces: [],
-          isAllowedResource: isAllowedResource(allowedResourcesState),
-        } as unknown as Cluster;
+          accessibleNamespaces: observable.array(),
+          shouldShowResource: (kind) => allowedResourcesState.has(formatKubeApiResource(kind)),
+        } as Partial<Cluster> as Cluster;
 
         windowDi.override(activeKubernetesClusterInjectable, () =>
           computed(() => catalogEntityFromCluster(clusterStub)),
@@ -499,26 +523,15 @@ export const getApplicationBuilder = () => {
           api: windowDi.inject(namespaceApiInjectable),
           items: namespaceItems,
           selectNamespaces: () => {},
+          selectSingle: () => {},
           getByPath: () => undefined,
           pickOnlySelected: () => [],
           isSelectedAll: () => false,
           getTotalCount: () => namespaceItems.length,
         } as Partial<NamespaceStore> as NamespaceStore;
 
-        const clusterFrameContextFake = new ClusterFrameContext(
-          clusterStub,
-
-          {
-            namespaceStore: namespaceStoreStub,
-          },
-        );
-
         windowDi.override(namespaceStoreInjectable, () => namespaceStoreStub);
         windowDi.override(hostedClusterInjectable, () => clusterStub);
-        windowDi.override(clusterFrameContextInjectable, () => clusterFrameContextFake);
-
-        // Todo: get rid of global state.
-        KubeObjectStore.defaultContext.set(clusterFrameContextFake);
       });
 
       return builder;
@@ -555,7 +568,7 @@ export const getApplicationBuilder = () => {
       },
 
       enable: (...extensions) => {
-        builder.beforeWindowStart((windowDi) => {
+        builder.afterWindowStart((windowDi) => {
           const rendererExtensionInstances = extensions.map((options) =>
             getExtensionFakeForRenderer(
               windowDi,
@@ -570,7 +583,7 @@ export const getApplicationBuilder = () => {
           );
         });
 
-        builder.beforeApplicationStart((mainDi) => {
+        builder.afterApplicationStart((mainDi) => {
           const mainExtensionInstances = extensions.map((extension) =>
             getExtensionFakeForMain(mainDi, extension.id, extension.name, extension.mainOptions || {}),
           );
@@ -584,7 +597,7 @@ export const getApplicationBuilder = () => {
       },
 
       disable: (...extensions) => {
-        builder.beforeWindowStart(windowDi => {
+        builder.afterWindowStart(windowDi => {
           extensions
             .map((ext) => ext.id)
             .forEach(
@@ -592,7 +605,7 @@ export const getApplicationBuilder = () => {
             );
         });
 
-        builder.beforeApplicationStart(mainDi => {
+        builder.afterApplicationStart(mainDi => {
           extensions
             .map((ext) => ext.id)
             .forEach(
@@ -602,11 +615,11 @@ export const getApplicationBuilder = () => {
       },
     },
 
-    allowKubeResource: (resourceName) => {
+    allowKubeResource: (resource) => {
       environment.onAllowKubeResource();
 
       runInAction(() => {
-        allowedResourcesState.push(resourceName);
+        allowedResourcesState.add(formatKubeApiResource(resource));
       });
 
       return builder;
@@ -622,6 +635,16 @@ export const getApplicationBuilder = () => {
       return builder;
     },
 
+    afterApplicationStart(callback) {
+      if (applicationHasStarted) {
+        callback(mainDi);
+      }
+
+      afterApplicationStartCallbacks.push(callback);
+
+      return builder;
+    },
+
     beforeWindowStart(callback) {
       const alreadyRenderedWindows = builder.applicationWindow.getAll();
 
@@ -647,29 +670,11 @@ export const getApplicationBuilder = () => {
     },
 
     startHidden: async () => {
-      mainDi.inject(lensProxyPortInjectable).set(42);
-
-      for (const callback of beforeApplicationStartCallbacks) {
-        await callback(mainDi);
-      }
-
-      mainDi.override(shouldStartHiddenInjectable, () => true);
-      await mainDi.inject(startMainApplicationInjectable);
-
-      applicationHasStarted = true;
+      await startApplication({ shouldStartHidden: true });
     },
 
     async render() {
-      mainDi.inject(lensProxyPortInjectable).set(42);
-
-      for (const callback of beforeApplicationStartCallbacks) {
-        await callback(mainDi);
-      }
-
-      mainDi.override(shouldStartHiddenInjectable, () => false);
-      await mainDi.inject(startMainApplicationInjectable);
-
-      applicationHasStarted = true;
+      await startApplication({ shouldStartHidden: false });
 
       return builder
         .applicationWindow
