@@ -2,23 +2,17 @@
  * Copyright (c) OpenLens Authors. All rights reserved.
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
-import { injectSystemCAs } from "../../../common/system-ca";
 import { getInjectable } from "@ogre-tools/injectable";
-import { beforeFrameStartsInjectionToken } from "../../before-frame-starts/before-frame-starts-injection-token";
+import { beforeFrameStartsSecondInjectionToken } from "../../before-frame-starts/tokens";
+import injectSystemCAsInjectable from "../../../common/certificate-authorities/inject-system-cas.injectable";
 
 const setupSystemCaInjectable = getInjectable({
   id: "setup-system-ca",
-
-  instantiate: () => ({
+  instantiate: (di) => ({
     id: "setup-system-ca",
-    run: async () => {
-      await injectSystemCAs();
-    },
+    run: di.inject(injectSystemCAsInjectable),
   }),
-
-  causesSideEffects: true,
-
-  injectionToken: beforeFrameStartsInjectionToken,
+  injectionToken: beforeFrameStartsSecondInjectionToken,
 });
 
 export default setupSystemCaInjectable;
