@@ -4,21 +4,22 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import userStoreInjectable from "../../common/user-store/user-store.injectable";
-import { beforeFrameStartsInjectionToken } from "../before-frame-starts/before-frame-starts-injection-token";
+import { beforeFrameStartsSecondInjectionToken } from "../before-frame-starts/tokens";
 import initDefaultUpdateChannelInjectable from "../vars/default-update-channel/init.injectable";
 
 const initUserStoreInjectable = getInjectable({
   id: "init-user-store",
-  instantiate: (di) => {
-    const userStore = di.inject(userStoreInjectable);
+  instantiate: (di) => ({
+    id: "init-user-store",
+    run: () => {
+      // This must be done here so as to actually only be instantiated after the dependencies are
+      const userStore = di.inject(userStoreInjectable);
 
-    return {
-      id: "init-user-store",
-      run: () => userStore.load(),
-      runAfter: di.inject(initDefaultUpdateChannelInjectable),
-    };
-  },
-  injectionToken: beforeFrameStartsInjectionToken,
+      return userStore.load();
+    },
+    runAfter: di.inject(initDefaultUpdateChannelInjectable),
+  }),
+  injectionToken: beforeFrameStartsSecondInjectionToken,
 });
 
 export default initUserStoreInjectable;
