@@ -4,10 +4,8 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import ipcRendererInjectable from "./ipc-renderer.injectable";
+import type { RequestFromChannel } from "../../../common/utils/channel/request-from-channel-injection-token";
 import { requestFromChannelInjectionToken } from "../../../common/utils/channel/request-from-channel-injection-token";
-import { pipeline } from "@ogre-tools/fp";
-import { tentativeStringifyJson } from "../../../common/utils/tentative-stringify-json";
-import { tentativeParseJson } from "../../../common/utils/tentative-parse-json";
 
 const requestFromChannelInjectable = getInjectable({
   id: "request-from-channel",
@@ -15,13 +13,7 @@ const requestFromChannelInjectable = getInjectable({
   instantiate: (di) => {
     const ipcRenderer = di.inject(ipcRendererInjectable);
 
-    return async (channel, ...[request]) =>
-      await pipeline(
-        request,
-        tentativeStringifyJson,
-        (req) => ipcRenderer.invoke(channel.id, req),
-        tentativeParseJson,
-      );
+    return ((channel, request) => ipcRenderer.invoke(channel.id, request)) as RequestFromChannel;
   },
 
   injectionToken: requestFromChannelInjectionToken,
