@@ -3,20 +3,20 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { beforeFrameStartsInjectionToken } from "../../before-frame-starts/before-frame-starts-injection-token";
+import { beforeFrameStartsSecondInjectionToken } from "../../before-frame-starts/tokens";
 import buildVersionInjectable from "./build-version.injectable";
 
 const initializeBuildVersionInjectable = getInjectable({
   id: "initialize-build-version",
-  instantiate: (di) => {
-    const buildVersion = di.inject(buildVersionInjectable);
+  instantiate: (di) => ({
+    id: "initialize-build-version",
+    run: async () => {
+      const buildVersion = di.inject(buildVersionInjectable);
 
-    return {
-      id: "initialize-build-version",
-      run: () => buildVersion.init(),
-    };
-  },
-  injectionToken: beforeFrameStartsInjectionToken,
+      await buildVersion.init();
+    },
+  }),
+  injectionToken: beforeFrameStartsSecondInjectionToken,
 });
 
 export default initializeBuildVersionInjectable;
