@@ -3,22 +3,22 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { beforeFrameStartsInjectionToken } from "../../before-frame-starts/before-frame-starts-injection-token";
+import { beforeFrameStartsSecondInjectionToken } from "../../before-frame-starts/tokens";
 import initReleaseChannelInjectable from "../release-channel/init.injectable";
 import defaultUpdateChannelInjectable from "../../../features/application-update/common/selected-update-channel/default-update-channel.injectable";
 
 const initDefaultUpdateChannelInjectable = getInjectable({
   id: "init-default-update-channel",
-  instantiate: (di) => {
-    const defaultUpdateChannel = di.inject(defaultUpdateChannelInjectable);
+  instantiate: (di) => ({
+    id: "init-default-update-channel",
+    run: async () => {
+      const defaultUpdateChannel = di.inject(defaultUpdateChannelInjectable);
 
-    return {
-      id: "init-default-update-channel",
-      run: () => defaultUpdateChannel.init(),
-      runAfter: di.inject(initReleaseChannelInjectable),
-    };
-  },
-  injectionToken: beforeFrameStartsInjectionToken,
+      await defaultUpdateChannel.init();
+    },
+    runAfter: di.inject(initReleaseChannelInjectable),
+  }),
+  injectionToken: beforeFrameStartsSecondInjectionToken,
 });
 
 export default initDefaultUpdateChannelInjectable;
