@@ -4,21 +4,21 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import releaseChannelInjectable from "../../../common/vars/release-channel.injectable";
-import { beforeFrameStartsInjectionToken } from "../../before-frame-starts/before-frame-starts-injection-token";
+import { beforeFrameStartsSecondInjectionToken } from "../../before-frame-starts/tokens";
 import initSemanticBuildVersionInjectable from "../semantic-build-version/init.injectable";
 
 const initReleaseChannelInjectable = getInjectable({
   id: "init-release-channel",
-  instantiate: (di) => {
-    const releaseChannel = di.inject(releaseChannelInjectable);
+  instantiate: (di) => ({
+    id: "init-release-channel",
+    run: async () => {
+      const releaseChannel = di.inject(releaseChannelInjectable);
 
-    return {
-      id: "init-release-channel",
-      run: () => releaseChannel.init(),
-      runAfter: di.inject(initSemanticBuildVersionInjectable),
-    };
-  },
-  injectionToken: beforeFrameStartsInjectionToken,
+      await releaseChannel.init();
+    },
+    runAfter: di.inject(initSemanticBuildVersionInjectable),
+  }),
+  injectionToken: beforeFrameStartsSecondInjectionToken,
 });
 
 export default initReleaseChannelInjectable;
